@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2006 MySQL AB
+/* Copyright (c) 2000, 2011, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 
 /* A lexical scanner on a temporary buffer with a yacc interface */
@@ -32,10 +32,10 @@ sys_var_long_ptr trg_new_row_fake_var(0, 0);
 
 /* Macros to look like lex */
 
-#define yyGet()		*(lip->ptr++)
-#define yyGetLast()	lip->ptr[-1]
-#define yyPeek()	lip->ptr[0]
-#define yyPeek2()	lip->ptr[1]
+#define yyGet()		((uchar)*(lip->ptr++))
+#define yyGetLast()	((uchar)lip->ptr[-1])
+#define yyPeek()	((uchar)lip->ptr[0])
+#define yyPeek2()	((uchar)lip->ptr[1])
 #define yyUnget()	lip->ptr--
 #define yySkip()	lip->ptr++
 #define yyLength()	((uint) (lip->ptr - lip->tok_start)-1)
@@ -109,7 +109,7 @@ st_parsing_options::reset()
 }
 
 Lex_input_stream::Lex_input_stream(THD *thd,
-                                   const char* buffer,
+                                   char* buffer,
                                    unsigned int length)
 : m_thd(thd),
   yylineno(1),
@@ -530,7 +530,7 @@ static inline uint int_token(const char *str,uint length)
 
 int MYSQLlex(void *arg, void *yythd)
 {
-  reg1	uchar c;
+  reg1	uchar UNINIT_VAR(c);
   bool comment_closed;
   int	tokval, result_state;
   uint length;
@@ -550,7 +550,6 @@ int MYSQLlex(void *arg, void *yythd)
   lip->tok_start=lip->tok_end=lip->ptr;
   state=lip->next_state;
   lip->next_state=MY_LEX_OPERATOR_OR_IDENT;
-  LINT_INIT(c);
   for (;;)
   {
     switch (state) {
@@ -581,7 +580,7 @@ int MYSQLlex(void *arg, void *yythd)
         state=MY_LEX_COMMENT;
         break;
       }
-      yylval->lex_str.str=(char*) (lip->ptr=lip->tok_start);// Set to first chr
+      yylval->lex_str.str=lip->ptr=(char*)lip->tok_start;// Set to first chr
       yylval->lex_str.length=1;
       c=yyGet();
       if (c != ')')
@@ -813,9 +812,11 @@ int MYSQLlex(void *arg, void *yythd)
 	  }
 	}
 #ifdef USE_MB
-	else if (var_length < 1)
-	  break;				// Error
-	lip->ptr+= var_length-1;
+	else if (use_mb(cs))
+        {
+          if ((var_length= my_ismbchar(cs, lip->ptr-1, lip->end_of_query)))
+            lip->ptr+= var_length-1;
+        }
 #endif
       }
       if (double_quotes)
@@ -945,6 +946,9 @@ int MYSQLlex(void *arg, void *yythd)
       state = MY_LEX_START;		// Try again
       break;
     case MY_LEX_LONG_COMMENT:		/* Long C comment? */
+    {
+      char *version_mark= NULL;
+
       if (yyPeek() != '*')
       {
 	state=MY_LEX_CHAR;		// Probable division
@@ -955,6 +959,8 @@ int MYSQLlex(void *arg, void *yythd)
       if (yyPeek() == '!')		// MySQL command in comment
       {
 	ulong version=MYSQL_VERSION_ID;
+        version_mark= lip->ptr;
+
 	yySkip();
 	state=MY_LEX_START;
 	if (my_isdigit(cs,yyPeek()))
@@ -963,9 +969,18 @@ int MYSQLlex(void *arg, void *yythd)
 	}
 	if (version <= MYSQL_VERSION_ID)
 	{
-	  lex->in_comment=1;
+          lex->in_comment=1;
+          version_mark= NULL;
 	  break;
 	}
+        else
+        {
+          /*
+            Patch and skip the conditional comment to avoid it
+            being propagated infinitely (eg. to a slave).
+          */
+          *version_mark= ' ';
+        }
       }
       /*
         Discard:
@@ -994,8 +1009,13 @@ int MYSQLlex(void *arg, void *yythd)
       }
       /* Unbalanced comments with a missing '*' '/' are a syntax error */
       if (! comment_closed)
+      {
+        if (version_mark != NULL)
+          *version_mark= '!';
         return (ABORT_SYM);
+      }
       break;
+    }
     case MY_LEX_END_LONG_COMMENT:
       if (lex->in_comment && yyPeek() == '/')
       {
@@ -1212,6 +1232,8 @@ void st_select_lex::init_query()
   exclude_from_table_unique_test= no_wrap_view_item= FALSE;
   nest_level= 0;
   link_next= 0;
+  m_non_agg_field_used= false;
+  m_agg_func_used= false;
 }
 
 void st_select_lex::init_select()
@@ -1246,7 +1268,8 @@ void st_select_lex::init_select()
   non_agg_fields.empty();
   cond_value= having_value= Item::COND_UNDEF;
   inner_refs_list.empty();
-  full_group_by_flag= 0;
+  m_non_agg_field_used= false;
+  m_agg_func_used= false;
 }
 
 /*
